==> blockly-gamepad-1.0.1.tgz: package/README.md <==
## gamepad.js 🎮

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![GitHub release](https://img.shields.io/github/release/Paol-imi/gamepad.js.svg)](https://GitHub.com/Paol-imi/gamepad.js/releases/)
[![Built on Blockly](https://tinyurl.com/built-on-blockly)](https://github.com/google/blockly)

> A [Blockly](https://developers.google.com/blockly/) extension designed to develop games (made with love ❤).

## How it works 📘

This library helps you to create the Blockly structure of a game, allowing you to interact `asynchronously` with it using methods like `load()` & `reset()` to init the game, `play()` & `pause()` to start the game, `forward()` & `backward()` to move step-by-step through the blocks and others useful methods.

See the [full documentation](https://paol-imi.github.io/gamepad.js) .

## Games 🏆

-   [The aviator](https://github.com/Paol-imi/the-aviator). This is a first demo of the game, if you like it you're officially changelled to solve the final impossible level 😜.

-   [Coming soon](). Lot of games coming soon.

## Demo 🕹️

Try this [demo](https://paol-imi.github.io/gamepad.js/demo), it is a remake with `gamepad.js` of the [Maze](https://blockly-games.appspot.com/maze) game. <br> You can find the full code [here](https://github.com/Paol-imi/gamepad.js/tree/master/docs/demo).
<br><br>
![](docs/demo/images/demo.gif)

## Tips 💡

To get a `quick` feedback of what you can create with this library I suggest you to view both the `demo` and the `games` linked above.
I also advise you to view the `commented` code (both for games and for the demo).

==> blockly-gamepad-1.0.2.tgz: package/README.md <==
## Blockly-gamepad 🎮

[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![GitHub release](https://img.shields.io/github/release/Paol-imi/blockly-gamepad.svg)](https://GitHub.com/Paol-imi/blockly-gamepad/releases/)
[![npm version](https://badge.fury.io/js/blockly-gamepad.svg)](https://badge.fury.io/js/blockly-gamepad)
[![Built on Blockly](https://tinyurl.com/built-on-blockly)](https://github.com/google/blockly)

> A [Blockly](https://developers.google.com/blockly/) extension designed to develop games (made with love ❤).

## How it works 📘

This library helps you to create the Blockly structure of a game, allowing you to interact `asynchronously` with it using methods like `load()` & `reset()` to init the game, `play()` & `pause()` to start the game, `forward()` & `backward()` to move step-by-step through the blocks and others useful methods.

See the [full documentation](https://paol-imi.github.io/blockly-gamepad) .

## Games 🏆

-   [The aviator](https://github.com/Paol-imi/the-aviator). This is a first demo of the game, if you like it you're officially changelled to solve the final impossible level 😜.

-   [Coming soon](). Lot of games coming soon.

## Demo 🕹️

Try this [demo](https://paol-imi.github.io/blockly-gamepad/demo), it is a remake with `blockly-gamepad` of the [Maze](https://blockly-games.appspot.com/maze) game. <br> You can find the full code [here](https://github.com/Paol-imi/blockly-gamepad/tree/master/docs/demo).
<br><br>
![](docs/demo/images/demo.gif)

## Tips 💡

To get a `quick` feedback of what you can create with this library I suggest you to view both the `demo` and the `games` linked above.
I also advise you to view the `commented` code (both for games and for the demo).
